@@ -65,6 +65,7 @@ Keys in stack list:
 Keys in breakpoints view:
 
     enter - edit breakpoint
+    d - delete breakpoint
 
 License:
 --------
@@ -1135,6 +1136,8 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "a terminal. If you've worked with the excellent (but nowadays "
                     "ancient) DOS-based Turbo Pascal or C tools, PuDB's UI might "
                     "look familiar.\n\n"
+                    "New features in version 2011.2:\n\n"
+                    "- Fix for post-mortem debugging (submitted by 'Sundance')\n\n"
                     "New features in version 2011.1:\n\n"
                     "- Breakpoints saved between sessions\n"
                     "- A new 'dark vim' theme\n"
